translate.storage.zip.ZIPFile

Package translate :: Package storage :: Module zip :: Class ZIPFile |
[hide private]
[frames] | no frames]

# Class ZIPFile

source code

This class represents a ZIP file like a directory.

Instance Methods | [hide private]
__init__(self, filename=None) | source code
unit_iter(self) Iterator over all the units in all the files in this zip file. | source code
scanfiles(self) Populate the internal file data. | source code
Inherited from `directory.Directory`: `file_iter`, `getfiles`, `getunits`

Method Details | [hide private]

### __init__(self, filename=None) (Constructor) | source code
Overrides: directory.Directory.__init__

### unit_iter(self) | source code
Iterator over all the units in all the files in this zip file. Overrides: directory.Directory.unit_iter

### scanfiles(self) | source code
Populate the internal file data. Overrides: directory.Directory.scanfiles